==> pixi-0.0.4.tar.gz: lib/pixi.dart <==
library pixi;

import 'dart:math';
import 'dart:html';
import 'dart:async';
import 'dart:convert';
import 'dart:web_gl' as GL;
import 'dart:collection';
import 'dart:typed_data';

part 'src/core/matrix.dart';
part 'src/core/colour.dart';

part 'src/textures/base_texture.dart';
part 'src/textures/texture.dart';

part 'src/display/display_object.dart';
part 'src/display/display_object_container.dart';
part 'src/display/graphics.dart';
part 'src/display/stage.dart';
part 'src/display/sprite.dart';
part 'src/display/movie_clip.dart';
part 'src/display/canvas_text.dart';
part 'src/display/bitmap_text.dart';
part 'src/display/tiling_sprite.dart';

part 'src/loaders/asset_loader.dart';
part 'src/loaders/image_loader.dart';
part 'src/loaders/json_loader.dart';
part 'src/loaders/bitmap_font_loader.dart';

part 'src/renderers/renderer.dart';
part 'src/renderers/canvas/canvas_renderer.dart';
part 'src/renderers/canvas/canvas_graphics.dart';

part 'src/renderers/webgl/gl_renderer.dart';
part 'src/renderers/webgl/gl_graphics.dart';
//part 'src/renderers/webgl/gl_tiling_sprite.dart';

part 'src/renderers/webgl/shaders/base_shader.dart';
part 'src/renderers/webgl/shaders/sprite_shader.dart';
part 'src/renderers/webgl/shaders/graphics_shader.dart';
//part 'src/renderers/webgl/shaders/strip_shader.dart';
part 'src/renderers/webgl/shaders/multi_shader.dart';

part 'src/renderers/webgl/batch/base_batch.dart';
part 'src/renderers/webgl/batch/simple_batch.dart';
part 'src/renderers/webgl/batch/multi_batch.dart';

part 'src/utils/polyk.dart';

==> pixi-0.1.0.tar.gz: lib/pixi.dart <==
library pixi;

import 'dart:math';
import 'dart:html';
import 'dart:async';
import 'dart:convert';
import 'dart:web_gl' as GL;
//import 'dart:collection';
import 'dart:typed_data';

part 'src/core/matrix.dart';
part 'src/core/colour.dart';

part 'src/textures/base_texture.dart';
part 'src/textures/texture.dart';

part 'src/display/display_object.dart';
part 'src/display/display_object_container.dart';
part 'src/display/graphics.dart';
part 'src/display/stage.dart';
part 'src/display/sprite.dart';
part 'src/display/movie_clip.dart';
part 'src/display/canvas_text.dart';
part 'src/display/bitmap_text.dart';
part 'src/display/tiling_sprite.dart';

part 'src/loaders/asset_loader.dart';
part 'src/loaders/image_loader.dart';
part 'src/loaders/json_loader.dart';
part 'src/loaders/bitmap_font_loader.dart';

part 'src/renderers/renderer.dart';
part 'src/renderers/canvas/canvas_renderer.dart';
part 'src/renderers/canvas/canvas_graphics.dart';

part 'src/renderers/webgl/gl_renderer.dart';
part 'src/renderers/webgl/gl_graphics.dart';

part 'src/renderers/webgl/shaders/base_shader.dart';
part 'src/renderers/webgl/shaders/sprite_shader.dart';
part 'src/renderers/webgl/shaders/graphics_shader.dart';
//part 'src/renderers/webgl/shaders/strip_shader.dart';
part 'src/renderers/webgl/shaders/multi_shader.dart';

part 'src/renderers/webgl/batch/base_batch.dart';
part 'src/renderers/webgl/batch/simple_batch.dart';
part 'src/renderers/webgl/batch/multi_batch.dart';

part 'src/interaction/interactive.dart';
part 'src/interaction/interaction_manager.dart';
part 'src/interaction/hit_area.dart';

part 'src/utils/polyk.dart';
